"""."""

from association_studio.score_driver.score_driver import ScoreDriver


def test_next(driver: ScoreDriver) -> None:
    assert driver.metric_index == 0
    driver.next()
    assert driver.metric_index == 1
