"""."""

from association_studio.app.back import AssociationStudioBackend


def test_next_metric(be: AssociationStudioBackend) -> None:
    be.next_metric()
    assert be.score_driver.metric_index == 1
