"""."""

from typing import Sequence


def get_multi_line(name: str) -> tuple[str] | tuple[str, str]:
    if name == 'mahalanobis-size-modulated':
        return 'mahalanobis', 'size-modulated'
    else:
        return (name,)


def get_labels(names: Sequence[str]) -> list[str]:
    """."""
    labels = []
    for name in names:
        labels.append('\n'.join(get_multi_line(name)))
    return labels
