import matplotlib.pyplot as plt


def get_fig_axes() -> tuple[plt.Figure, plt.Axes, plt.Axes]:
    fig, (ax_bts, ax_fig) = plt.subplots(1, 2, figsize=(10, 4.5))
    ax_bts.set_position([0.05, 0.06, 0.3, 0.85])
    ax_fig.set_position([0.5, 0.06, 0.45, 0.85])
    fig.canvas.manager.set_window_title('Association Studio: metrics')
    return fig, ax_fig, ax_bts
