"""."""

from association_studio.score_driver.metric_labels import get_labels, get_multi_line


def test_get_multi_line() -> None:
    assert get_multi_line('any-thing') == ('any-thing',)
    assert get_multi_line('mahalanobis-size-modulated') == ('mahalanobis', 'size-modulated')


def test_get_labels() -> None:
    assert get_labels(['1-2', '1-2-3']) == ['1-2', '1-2-3']
