"""."""

import pytest

from association_studio.score_driver.score_driver import ScoreDriver


def test_flip_selection(driver: ScoreDriver) -> None:
    driver.flip_selection('mahalanobis')
    ref = True, True, False, True, True, True, True
    assert driver.metric_selection == pytest.approx(ref)
