"""."""

import numpy as np
import pytest

from association_studio.exp_metrics.iou_like_two_yaw import IouLikeTwoYaw


def test_two_yaw_nu_scenes(driver: IouLikeTwoYaw) -> None:
    vec_z = np.array((1.0, 2.0, 3.0, 4.0, 0.0, 0.0, 7.0, 8.0, 9.0, 10.0))
    driver.two_yaw_nu_scenes(vec_z)
    ref = 1.0, 2.0, 3.0, 0.5076923076923079, 0.0, 0.0, -0.8615384615384615, 8.0, 9.0, 10.0
    assert vec_z == pytest.approx(ref)
