"""."""

from association_studio.app.front import AssociationFrontend


def test_it(front: AssociationFrontend) -> None:
    front.on_clicked_buttons('mahalanobis')
    ref = [
        'giou-axes-aligned',
        'giou-yaw',
        'mahalanobis-size-modulated',
        'iou-like-dia-mah',
        'iou-like-dia-slater',
        'iou-like-two-yaw',
    ]
    assert front.back.score_driver.get_names() == ref
    assert len(front.bar.patches) == 6
